pub struct LicenseFile {
pub license_expr: Expression,
pub path: Utf8PathBuf,
pub confidence: f32,
pub kind: LicenseFileKind,
}Fields
license_expr: ExpressionThe SPDX requirement expression detected for the file
path: Utf8PathBufFull path of the file which had license data in it
confidence: f32The confidence score for the license, the closer to the canonical license text it is, the closer it approaches 1.0
kind: LicenseFileKindThe contents of the file