pub struct Krate(pub Package);Tuple Fields
0: PackageMethods from Deref<Target = Package>
Sourcepub fn license_file(&self) -> Option<Utf8PathBuf>
pub fn license_file(&self) -> Option<Utf8PathBuf>
Full path to the license file if one is present in the manifest
Sourcepub fn readme(&self) -> Option<Utf8PathBuf>
pub fn readme(&self) -> Option<Utf8PathBuf>
Full path to the readme file if one is present in the manifest